package com.nisum.product.controller;

import com.nisum.product.dto.KafkaPublisherResponse;
import com.nisum.product.dto.ProductOffers;
import com.nisum.product.service.ProductsOfferService;
import lombok.extern.slf4j.Slf4j;
import org.apache.spark.sql.streaming.StreamingQueryException;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.HttpStatus;
import org.springframework.http.MediaType;
import org.springframework.http.codec.multipart.FilePart;
import org.springframework.web.bind.annotation.*;
import reactor.core.publisher.Flux;

import java.util.concurrent.TimeoutException;

@Slf4j
@RestController
@RequestMapping(path = "/product")
public class ProductController {


    @Autowired
    private ProductsOfferService productsOfferService;

    @PostMapping(value = "/upload-data", consumes = MediaType.MULTIPART_FORM_DATA_VALUE, produces = MediaType.APPLICATION_JSON_VALUE)
    @ResponseStatus(value = HttpStatus.OK)
    public Flux<KafkaPublisherResponse> upload(@RequestPart("files") Flux<FilePart> filePartFlux){

        return productsOfferService.saveAndProcess(filePartFlux);
    }

    @GetMapping(value = "/get", consumes = MediaType.MULTIPART_FORM_DATA_VALUE, produces = MediaType.APPLICATION_JSON_VALUE)
    @ResponseStatus(value = HttpStatus.OK)
    public Flux<ProductOffers> getProductData(@RequestParam("batchId") String batchId) throws TimeoutException, StreamingQueryException {

        return productsOfferService.getProductOffers(batchId);
    }




}
